package com.diagbot.process;

import com.diagbot.biz.push.entity.Item;
import com.diagbot.biz.push.entity.Lis;
import com.diagbot.dto.BillMsg;
import com.diagbot.dto.HighRiskNeoDTO;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.NodeNeoDTO;
import com.diagbot.dto.WordCrfDTO;
import com.diagbot.enums.TypeEnum;
import com.diagbot.model.label.PacsLabel;
import com.diagbot.util.CoreUtil;
import com.diagbot.util.MsgUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description: 高风险总入口
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class HighRiskProcess {

    /**
     * 处理业务
     *
     * @param highRiskNeoDTOList
     * @param res
     */
    public void process(List<HighRiskNeoDTO> highRiskNeoDTOList, IndicationDTO res, WordCrfDTO wordCrfDTO) {
        for (HighRiskNeoDTO highRiskNeoDTO : highRiskNeoDTOList) {
            System.out.println(highRiskNeoDTO);
            String type = highRiskNeoDTO.getType();
            if (highRiskNeoDTO.getIsHighrisk()) {
                BillMsg billMsg = new BillMsg();
                if (TypeEnum.operation.getName().equals(type)) {
                    billMsg.setMsg(highRiskNeoDTO.getName() + "为高风险手术，请留意");
                } else if (TypeEnum.drug.getName().equals(type)) {
                    billMsg.setMsg(highRiskNeoDTO.getName() + "为" + highRiskNeoDTO.getHighLevel() + "药品，请留意");
                }

                billMsg.setOrderName(highRiskNeoDTO.getName());
                billMsg.setOrderStandName(highRiskNeoDTO.getStandname());
                billMsg.setType(type);
                res.getHighRiskList().add(billMsg);
            } else {
                List<Item> diag = wordCrfDTO.getDiag();
                List<Lis> lisList = wordCrfDTO.getLis();
                PacsLabel pacsLabel = wordCrfDTO.getPacsLabel();
                // 复杂情况高危手术
                if (TypeEnum.operation.getName().equals(type)) {
                    List<NodeNeoDTO> factor = highRiskNeoDTO.getFactor();
                    for (NodeNeoDTO nodeNeoDTO : factor) {
                        if (TypeEnum.disease.getName().equals(nodeNeoDTO.getTermtype())) {
                            String name = nodeNeoDTO.getName();
                            for (Item item : diag) {
                                if (item.getUniqueName().equals(name)) {
                                    BillMsg billMsg = MsgUtil.getComplexOperationMsg( item.getName(), highRiskNeoDTO.getName(),nodeNeoDTO.getTermtype());
                                    res.getHighRiskList().add(billMsg);
                                }
                            }
                        } else if (TypeEnum.lis.getName().equals(nodeNeoDTO.getTermtype())) {
                            for (Lis lis : lisList) {
                                if (lis.getUniqueName().equals(nodeNeoDTO.getName())) {
                                    Map<String, Object> map = CoreUtil.compareLis(nodeNeoDTO, lis);
                                    if ((Boolean) map.get("flag") == true) {
                                        BillMsg billMsg = MsgUtil.getComplexOperationMsg((String)map.get("msg"), highRiskNeoDTO.getName(), nodeNeoDTO.getTermtype());
                                        res.getHighRiskList().add(billMsg);
                                    }
                                }
                            }
                        } else if (TypeEnum.pacs.getName().equals(nodeNeoDTO.getTermtype())) {
                            List<Item> pacsDescList = pacsLabel.getRes();
                            //辅检匹配结果
                            for (Item item : pacsDescList) {
                                if (item.getUniqueName().equals(nodeNeoDTO.getVal())) {
                                    BillMsg billMsg = MsgUtil.getComplexOperationMsg(item.getName(), highRiskNeoDTO.getName(), nodeNeoDTO.getTermtype());
                                    res.getHighRiskList().add(billMsg);
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
